@@ -1,7 +1,7 @@
 # -*- coding: utf-8 -*-
 #
 # This file is part of urlwatch (https://thp.io/2008/urlwatch/).
-# Copyright (c) 2008-2016 Thomas Perl <thp.io/about>
+# Copyright (c) 2008-2018 Thomas Perl <m@thp.io>
 # All rights reserved.
 #
 # Redistribution and use in source and binary forms, with or without
@@ -31,6 +31,8 @@
 import logging
 import os
 import platform
+import subprocess
+import shlex
 
 logger = logging.getLogger(__name__)
 
@@ -87,3 +89,13 @@ def atomic_rename(old_filename, new_filename):
             os.remove(new_old_filename)
     else:
         os.rename(old_filename, new_filename)
+
+
+def edit_file(filename):
+    editor = os.environ.get('EDITOR', None)
+    if not editor:
+        editor = os.environ.get('VISUAL', None)
+    if not editor:
+        raise SystemExit('Please set $VISUAL or $EDITOR.')
+
+    subprocess.check_call(shlex.split(editor) + [filename])
